AdobeVisitor class
Constructors
- AdobeVisitor(String experienceCloudId, int idSyncTtl, int region, String blob, int nextRefresh)
-
AdobeVisitor.fromJson(Map<
String, dynamic> json)
Properties
- blob → String
-
final
- experienceCloudId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idSyncTtl → int
-
final
- nextRefresh → int
-
final
- region → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited